@@ -120,15 +120,17 @@ instance Pretty CStat where
     pretty c@(CCompound _ _ _) = prettyPrec 0 c
     pretty (CIf expr stat estat _) =
         ii $  text "if" <+> text "(" <> pretty expr <> text ")"
-                $+$ prettyPrec (-1) stat
-              $$ maybeP prettyElse estat
+                $+$ prettyThen stat
+                $$  maybeP prettyElse estat
       where
+        prettyThen stat@(CIf _ _ _ _) = text "{" $+$ prettyPrec (-1) stat $$ text "}"
+        prettyThen stat = prettyPrec (-1) stat
         prettyElse (CIf else_if_expr else_if_stat else_stat _) =
           text "else if" <+> text "(" <> pretty else_if_expr <> text ")"
             $+$ prettyPrec (-1) else_if_stat
           $$ maybeP prettyElse else_stat
         prettyElse else_stmt =
-          text "else" <+> prettyPrec (-1) else_stmt
+          text "else" $+$ prettyPrec (-1) else_stmt
 
     pretty (CSwitch expr stat _) =
         ii $ text "switch" <+> text "(" <> pretty expr <> text ")"
@@ -217,7 +219,12 @@ instance Pretty CDeclSpec where
     pretty (CTypeQual qu) = pretty qu
 
 instance Pretty CStorageSpec where
-    pretty sp = text (show sp)
+    pretty (CAuto _) = text "auto"
+    pretty (CRegister _) = text "register"
+    pretty (CStatic _) = text "static"
+    pretty (CExtern _) = text "extern"
+    pretty (CTypedef _) = text "typedef"
+    pretty (CThread _) = text "__thread"
 
 instance Pretty CTypeSpec where
     pretty (CVoidType _)        = text "void"
@@ -407,10 +414,7 @@ instance Pretty CExpr where
     prettyPrec _p (CCompoundLit decl initl _) =
         parens (pretty decl) <+> (braces . hsep . punctuate comma) (map p initl) where
         p ([], initializer)           = pretty initializer
-        p ([struct_mem], initializer) = pretty struct_mem <+> text "=" <+> pretty initializer
-        p (badDecls , initializer)  =
-            error $ "Inconsistent AST: more than one left-hand-side in CCompoundLit init-list entry" ++
-                    (show $ (hsep $ punctuate comma $ map pretty badDecls) <+> text "=" <+> pretty initializer)
+        p (mems, initializer) = hcat (punctuate (text ".") (map pretty mems)) <+> text "=" <+> pretty initializer
 
     prettyPrec _p (CStatExpr stat _) =
         text "(" <> pretty stat <> text ")"
